The stuff in this folder doesn't really belong to the temci tool but builds
on top of it some cool applications, like a benchmarksgame inspired comparison
of different implementations of several languages.
The tools may depend on other code or packages than the temci tool itself.